#!/bin/bash

if [ $# -eq 0 ]; then
  # no argument, assuming returning remote
  MODE="REMOTE"
else
  MODE=($1)
fi

# Convert mode to lower case
MODE=${MODE,,}
# User to run mympd

if [ "$MODE" == "start" ]; then
  # Wait for MPD to start
  RUNNING=""
  COUNT=0
  while [ ${COUNT} -lt 60 ]; do
    RUNNING=$(netstat -an|grep 6600|grep LISTEN)
    if [ ! -z "${RUNNING}" ]; then
      chown mympd:mympd /var/lib/mympd -R
      mympd -u mympd 2>> /tmp/stderr  >> /tmp/stdout &
      break
    fi
    ((COUNT++))
    sleep 1
  done
elif [ "$MODE" == "stop" ]; then
  COUNT=0
  PID=$(pgrep ^mympd)
  while [ ! -z "$PID" ]; do
    kill -9 $PID
    ((COUNT++))
    if [ $COUNT -gt 5 ]; then
      break
    elif [ $COUNT -gt 2 ]; then
      sleep 0.5
    fi
    PID=$(pgrep ^mympd)
  done
elif [ "$MODE" == "install" ]; then
  curl -s https://artifacts.snakeoil-os.net/artifacts/mympd_$(uname -m).tar.bz2 -o /media/snakeoil_cache/mympd_$(uname -m).tar.bz2
  tar -xjf /media/snakeoil_cache/mympd_$(uname -m).tar.bz2 -C /usr/local/bin
  rm /var/lib/mympd/ -rf

  adduser --disabled-login --gecos "" mympd --no-create-home
  mympd -c

  echo 8080 | tee /var/lib/mympd/config/http_port > /dev/null
  echo 4343 | tee /var/lib/mympd/config/ssl_port >> /dev/null
  mkdir -p /var/lib/mympd/state
  echo /media/music | tee /var/lib/mympd/state/music_directory > /dev/null
elif [ "$MODE" == "remove" ]; then
  killall mympd
  deluser mympd
  rm /usr/local/bin/mympd* -f
else
  if [[ ( ! -f /var/www/scratch/no_remote) && ((-f /usr/bin/mympd) || (-f /usr/local/bin/mympd)) ]]; then
    HOST=$(hostname -I|awk '{print $1}')
    if [ -z "$HOSTNAME" ]; then
      HOST=$(hostname)
    fi
    echo "{\"url\": \"https://$HOST:4343/\", \"name\": \"myMPD\"}"
  fi
fi

